Index: main/waeup.kofa/trunk/src/waeup/kofa/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/interfaces.py	(revision 8756)
+++ main/waeup.kofa/trunk/src/waeup/kofa/interfaces.py	(revision 8757)
@@ -392,4 +392,5 @@
     email = Attribute("The email address of a user")
     phone = Attribute("The phone number of a user")
+    public_name = Attribute("The public name of a user")
 
 
@@ -410,4 +411,8 @@
         description = u'',
         required=False,)
+
+    public_name = schema.TextLine(
+        title = _(u'Public Name'),
+        required = False,)
 
 class IUserAccount(IKofaObject):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 8756)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 8757)
@@ -140,4 +140,5 @@
                              email=account.email,
                              phone=account.phone,
+                             public_name=account.public_name,
                              user_type=account.user_type)
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/userscontainer.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/userscontainer.py	(revision 8756)
+++ main/waeup.kofa/trunk/src/waeup/kofa/userscontainer.py	(revision 8757)
@@ -33,5 +33,6 @@
 
     def addUser(self, name, password, title=None,
-                description=None, email=None, phone=None, roles=[]):
+                description=None, email=None, phone=None,
+                public_name= None, roles=[]):
         """Add a new Account instance, created from parameters.
         """
@@ -41,5 +42,5 @@
         #    description = title
         self[name] = Account(name=name, password=password, title=title,
-                             description=description,
+                             description=description, public_name=public_name,
                              email=email, phone=phone, roles=roles)
         #self.logger.info('User account %s added.' % name)

Index: main/waeup.kofa/trunk/src/waeup/kofa/authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/authentication.py	(revision 8756)
+++ main/waeup.kofa/trunk/src/waeup/kofa/authentication.py	(revision 8757)
@@ -77,9 +77,9 @@
 
     A Kofa principal info is created with id, login, title, description,
-    phone, email and user_type.
+    phone, email, public_name and user_type.
     """
     grok.implements(IKofaPrincipalInfo)
 
-    def __init__(self, id, title, description, email, phone, user_type):
+    def __init__(self, id, title, description, email, phone, public_name, user_type):
         self.id = id
         self.title = title
@@ -87,4 +87,5 @@
         self.email = email
         self.phone = phone
+        self.public_name = public_name
         self.user_type = user_type
         self.credentialsPlugin = None
@@ -94,5 +95,5 @@
     """A portal principal.
 
     Kofa principals provide an extra `email`, `phone` and `user_type`
     attribute extending ordinary principals.
     """
@@ -101,5 +102,5 @@
 
     def __init__(self, id, title=u'', description=u'', email=u'',
-                 phone=None, user_type=u'', prefix=None):
+                 phone=None, public_name=u'', user_type=u'', prefix=None):
         self.id = id
         if prefix is not None:
@@ -110,4 +111,5 @@
         self.email = email
         self.phone = phone
+        self.public_name = public_name
         self.user_type = user_type
 
@@ -137,4 +139,5 @@
             self.info.email,
             self.info.phone,
+            self.info.public_name,
             self.info.user_type,
             authentication.prefix,
@@ -237,4 +240,5 @@
             email=account.email,
             phone=account.phone,
+            public_name=account.public_name,
             user_type=u'user')
 
@@ -249,4 +253,5 @@
             email=account.email,
             phone=account.phone,
+            public_name=account.public_name,
             user_type=u'user')
 
@@ -94,5 +95,5 @@
     """A portal principal.
 
-    Kofa principals provide an extra `email`, `phone` and `user_type`
+    Kofa principals provide an extra `email`, `phone`, `public_name` and `user_type`
     attribute extending ordinary principals.
     """